@@ -12,8 +12,9 @@ drawmap <- function(data, map,
 
     regions <- names(map)
     S <- length(regions)
+    is.in <- attr(map, "is.in")
     height2width <- attr(map, "height2width")
-    height2width <- height2width*1.1 # Legendenkorrektur
+    height2width <- height2width*1.1
 
     ## draw inner regions last: reorder therefore the map
     surrounding <- attr(map, "surrounding")
@@ -21,11 +22,8 @@ drawmap <- function(data, map,
     if(length(innerRegionInds)){
         regions <- c(regions[- innerRegionInds], regions[innerRegionInds])
         map <- c(map[- innerRegionInds], map[innerRegionInds])
-    }   
+    }
 
-    old.par <- par(no.readonly=TRUE)
-    on.exit(par(old.par))
-    
     if(!is.null(mar.min)){
         if(height2width > 1){
             side <- 17.5*(1-1/height2width)+mar.min/height2width
@@ -36,7 +34,7 @@ drawmap <- function(data, map,
             par(mar=c(top,mar.min,top,mar.min))
         }
     }
-    
+
     black <- grey(0)
     white <- grey(1)
 
@@ -48,17 +46,17 @@ drawmap <- function(data, map,
         xmin[i] <- min(map[[i]][, 1], na.rm = TRUE)
         xmax[i] <- max(map[[i]][, 1], na.rm = TRUE)
         ymin[i] <- min(map[[i]][, 2], na.rm = TRUE)
-        ymax[i] <- max(map[[i]][, 2], na.rm = TRUE)                  
+        ymax[i] <- max(map[[i]][, 2], na.rm = TRUE)
     }
     xlimits <- c(min(xmin), max(xmax))
     ylimits <- c(min(ymin) - (max(ymax) - min(ymin)) * 0.1, max(ymax))
 
     if(missing(data)){
         plot(xlimits, ylimits, type = "n", axes = FALSE, xlab="", ylab="", ...)
-        for (k in 1:S) 
+        for (k in 1:S)
             polygon(map[[k]][, 1], map[[k]][,2], lwd = 0.3, border = black)
     }
-    
+
     else{
         if(!is.data.frame(data))
             data <- read.table(data, header = TRUE)
@@ -69,9 +67,9 @@ drawmap <- function(data, map,
         regionvar <- data[, regionvar]
         regionvar <- regionvar[ord]
 
-        if(cols != "hcl" && cols != "hsv" && cols != "grey") { 
+        if(cols != "hcl" && cols != "hsv" && cols != "grey") {
             nrcolors <- length(cols)
-            if (swapcolors == TRUE) 
+            if (swapcolors == TRUE)
                 cols <- rev(cols)
         }
         else{
@@ -90,7 +88,7 @@ drawmap <- function(data, map,
         maxim <- max(plotvar, na.rm = TRUE)
         minim <- min(plotvar, na.rm = TRUE)
 
-        if(cols != "hcl" && cols != "hsv" && cols != "grey") { 
+        if(cols != "hcl" && cols != "hsv" && cols != "grey") {
             upperlimit <- 1
             lowerlimit <- -1
         }
@@ -99,10 +97,10 @@ drawmap <- function(data, map,
                 lowerlimit <- minim
                 upperlimit <- maxim
             }
-            else { 
+            else {
                 lowerlimit <- limits[1]
                 upperlimit <- limits[2]
-                
+
                 if (lowerlimit > minim) {
                     plotvar[plotvar < lowerlimit] <- lowerlimit
                     cat(paste("Note: lowerlimit is above minimum value (", lowerlimit, " > ", minim, ")\n"))
@@ -113,17 +111,17 @@ drawmap <- function(data, map,
                 }
             }
         }
-        
+
         if(pcat) {
             nrcolors <- 3
             upperlimit <- 1
             lowerlimit <- -1
-            if(cols != "hcl" && cols != "hsv" && cols != "grey")  
+            if(cols != "hcl" && cols != "hsv" && cols != "grey")
                 cols <- c(cols[1], cols[round(length(cols)/2 + 0.5)], cols[length(cols)])
         }
 
 
-        fill.colors <- cut(c(lowerlimit, plotvar, upperlimit),nrcolors) 
+        fill.colors <- cut(c(lowerlimit, plotvar, upperlimit),nrcolors)
         fill.colors <- fill.colors[c(-1, -length(fill.colors))]
         fill.colors <- as.vector(fill.colors, mode = "numeric")
 
@@ -133,7 +131,7 @@ drawmap <- function(data, map,
         }
         else{
             if (cols == "hcl") {
-                if (swapcolors == TRUE) 
+                if (swapcolors == TRUE)
                     h <- rev(h)
                 fill.colors <- colorspace::diverge_hcl(nrcolors,h=h,c=c,l=l)[fill.colors]
                 legend.colors <- colorspace::diverge_hcl(nrcolors,h=h,c=c,l=l)
@@ -149,7 +147,7 @@ drawmap <- function(data, map,
             }
             if (cols == "grey") {
                 fill.colors <- (fill.colors-1)/(nrcolors-1)
-                if (swapcolors == TRUE) 
+                if (swapcolors == TRUE)
                     fill.colors <- 1 - fill.colors
                 fill.colors <- grey(fill.colors)
                 legend.colors <- grey((0:(nrcolors-1))/(nrcolors-1))
@@ -157,18 +155,18 @@ drawmap <- function(data, map,
                     legend.colors <- rev(legend.colors)
             }
         }
-        
+
 
         plot(xlimits, ylimits, type = "n", axes = FALSE, col = white, xlab="", ylab="", ...)
-        
-        if(sum(!is.na(match(regions, regionvar))) == 0) 
+
+        if(sum(!is.na(match(regions, regionvar))) == 0)
             warning("map probably doesn't match datafile")
         block1 <- c()
         block2 <- c()
         for (k in 1:S) {
-            if (is.na(map[[k]][1, 1]) && is.na(map[[k]][1, 2])) 
+            if (is.na(map[[k]][1, 1]) && is.na(map[[k]][1, 2]))
                 block2 <- c(block2, k)
-            else 
+            else
                 block1 <- c(block1, k)
         }
         m <- match(regions, regionvar)
@@ -177,7 +175,7 @@ drawmap <- function(data, map,
                 polygon(map[[k]][, 1], map[[k]][, 2], col = white, border = FALSE)
                 polygon(map[[k]][, 1], map[[k]][, 2], density  = density, lwd = 0.3, col = black)
             }
-            else 
+            else
                 polygon(map[[k]][, 1], map[[k]][, 2], col = fill.colors[m[k]], border = black)
         }
         for (k in block2) {
@@ -185,7 +183,7 @@ drawmap <- function(data, map,
                 polygon(map[[k]][-1, 1], map[[k]][-1, 2], col = white, border = FALSE)
                 polygon(map[[k]][-1, 1], map[[k]][-1, 2], density = density, lwd = 0.3, col = black)
             }
-            else 
+            else
                 polygon(map[[k]][-1, 1], map[[k]][-1, 2], col = fill.colors[m[k]], border = black)
         }
 
@@ -197,32 +195,30 @@ drawmap <- function(data, map,
             xru <- xro <- xlimits[1] + 0.4 * (xlimits[2] - xlimits[1])
             step <- (xru - xlu)/nrcolors
             for (i in 0:(nrcolors - 1)) {
-                polygon(c(xlo + step * i, xlo + step * (i + 1), xlu + step * (i + 1), xlu + step * i), 
+                polygon(c(xlo + step * i, xlo + step * (i + 1), xlu + step * (i + 1), xlu + step * i),
                         c(ylo, yro, yru, ylu), col = legend.colors[i + 1], border = legend.colors[i + 1])
             }
             lines(c(xlo, xro, xru, xlu, xlo), c(ylo, yro, yru, ylu, ylo), col = black)
-            par(cex=cex.legend)
-            text(xlu + 0.5 * step, tylu, round(lowerlimit,4), col = black)
-            text(xru - 0.5 * step, tyru, round(upperlimit,4), col = black)
+            text(xlu + 0.5 * step, tylu, round(lowerlimit,4), col = black, cex = cex.legend)
+            text(xru - 0.5 * step, tyru, round(upperlimit,4), col = black, cex = cex.legend)
             
             if (lowerlimit + (upperlimit - lowerlimit)/3 < 0 && 0 < upperlimit - (upperlimit - lowerlimit)/3) {
                 help <- cut(c(0, lowerlimit, upperlimit), nrcolors)
                 help <- as.vector(help, mode = "numeric")
                 if(nrcolors%%2 == 0)
-                    text(xlu + step * (help[1]), tylu, "0", col = black)              
+                    text(xlu + step * (help[1]), tylu, "0", col = black, cex = cex.legend)              
                 else
-                    text(xlu + step * (help[1] - 0.5), tylu, "0", col = black)
+                    text(xlu + step * (help[1] - 0.5), tylu, "0", col = black, cex = cex.legend)
             }
         }
     }
     
-    par(cex=cex.names)
     if (drawnames == TRUE) {
         xpos <- (xmin + xmax)/2
         ypos <- (ymin + ymax)/2
-        text(xpos, ypos, labels = regions, col = black)
+        text(xpos, ypos, labels = regions, col = black, cex = cex.names)
     }
 
-
     return(invisible())
 }
+
